/***************************************************************************
                          specialgroups.h  -  description
                             -------------------
    begin                : Tue Oct 22 2002
    copyright            : (C) 2002 by Mike K. Bennett
    email                : mkb137b@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// Define the special groups here
#ifndef SPECIALGROUPS_H
#define SPECIALGROUPS_H

#include <qstring.h>

namespace SpecialGroups
{
  const QString INDIVIDUALS = "individuals";
  const QString ONLINE      = "online";
  const QString OFFLINE     = "offline";
  const QString ALLOWED     = "allowed";
  const QString REMOVED     = "removed";
}

#endif
